@@ -44,7 +44,7 @@ from google.cloud.functions.context import Context
 from functions_framework._of.v2.context import FunctionContext
 _FUNC_CTX = dict()
 KNATIVE_FUNC = "Knative"
-ASYNC = "OpenFuncAsync"
+ASYNC = "async"
 
 MAX_CONTENT_LENGTH = 10 * 1024 * 1024
 
