@@ -8,7 +8,7 @@ class Context(object):
 
 # FUNC_CONTEXT={"name":"faas.http","version":"v1.0.1","port":"8080","runtime":"Knative","prePlugins":["plugin-signature"],"postPlugins":["plugin-signature"]}
 class FunctionContext(object):
-    def __init__(self, name, version, port, runtime, inputs=None, outputs=None, prePlugins=None, postPlugins=None):
+    def __init__(self, name, version, port, runtime, inputs=None, outputs=None, prePlugins=None, postPlugins=None,pluginsTracing=None,out=None):
         self.name = name
         self.version = version
         self.port = port
@@ -17,6 +17,8 @@ class FunctionContext(object):
         self.outputs = outputs
         self.prePlugins = prePlugins
         self.postPlugins = postPlugins
+        self.pluginsTracing = pluginsTracing
+        self.out = out
         if self.inputs is not None and type(inputs) == dict :
             for key,input in  dict(inputs).items():
                 self.inputs[key] = Input(**input)
